from distutils.core import setup

setup(
        name            = 'djnester',
        version         = '1.1.0',
        py_modules      = ['nester'],
        author          = 'danjiang',
        author_email    = 'danjiang5956@gmail.com',
        url             = 'http://danthought.com',
        description     = 'A simple printer of nested lists',
    )
